@@ -199,6 +199,7 @@ class TransformerEncoder(nn.Module):
         attention_probs_dropout_prob=0.1,
         num_use_moe=10,
         use_moe=True,
+        dim_high=500,
     ):
         """
         Initializes the Transformer Encoder.
@@ -234,6 +235,7 @@ class TransformerEncoder(nn.Module):
                     hidden_size,
                     num_layers,
                     nn_type=nn_type,
+                    dim_high=hidden_size,
                 ) for _ in range(num_use_moe)
             ])
         else:
@@ -243,14 +245,15 @@ class TransformerEncoder(nn.Module):
                 hidden_size, 
                 num_layers,
                 nn_type=nn_type,
+                dim_high=hidden_size,
             )
         
         # Output fully connected layer
         self.fc = nn.Sequential(
-            NN_FCBNRL_MM(hidden_size, num_input_dim, use_RL=False),
+            NN_FCBNRL_MM(hidden_size, dim_high, use_RL=False),
         )
 
-    def network_single(self, num_input_dim, hidden_size, num_layers, nn_type='nn'):
+    def network_single(self, num_input_dim, hidden_size, num_layers, dim_high=500, nn_type='nn'):
         """
         Creates a single network (either ResNet or fully connected).
 
@@ -274,7 +277,7 @@ class TransformerEncoder(nn.Module):
                 layers.append(
                     NN_FCBNRL_MM(hidden_size, hidden_size)
                 )
-            layers.append(NN_FCBNRL_MM(hidden_size, hidden_size, use_RL=False))
+            layers.append(NN_FCBNRL_MM(hidden_size, dim_high, use_RL=False))
             enc = nn.Sequential(*layers)
         return enc
     
@@ -336,7 +339,9 @@ class DMTEVT_model(LightningModule):
         test_noise=False,
         norm_loss=False,
         temp=10,
+        all_g_l_weight=0.5,
         loss_type='L',
+        dim_high=500,
         **kwargs,
     ):
         """
@@ -379,6 +384,7 @@ class DMTEVT_model(LightningModule):
         self.save_hyperparameters()
 
         num_input_dim = self.hparams.num_input_dim
+        dim_high = self.hparams.dim_high
         self.init_exp_bool = False
         
         # Initialize the encoder
@@ -392,14 +398,15 @@ class DMTEVT_model(LightningModule):
             hidden_dropout_prob=T_hidden_dropout_prob,
             attention_probs_dropout_prob=T_attention_probs_dropout_prob,
             num_use_moe=num_use_moe,
+            dim_high=dim_high,
         )
         
         # Visualization network
         self.vis = self.InitNetworkMLP(
-            NS=[num_input_dim*num_use_moe, 500, vis_dim],
+            NS=[dim_high*num_use_moe, 500, vis_dim],
             last_relu=False, use_DO=False)
         # Embedding layer for experts
-        self.exp = nn.Embedding(self.hparams.num_use_moe, num_input_dim)
+        self.exp = nn.Embedding(self.hparams.num_use_moe, dim_high)
 
         # Load checkpoint if provided
         if ckpt_path is not None:
@@ -642,7 +649,7 @@ class DMTEVT_model(LightningModule):
             nu=nu
         ) 
         loss2 = loss2/loss2.detach()
-        loss = loss1 * 0.5 + loss2 * 0.5
+        loss = loss1 * self.hparams.all_g_l_weight + loss2 * (1 - self.hparams.all_g_l_weight)
 
         return loss
 
